@@ -101,6 +101,7 @@ gst_frame_positioner_update_properties (GstFramePositioner * pos,
 
   if (old_track_width && pos->width == old_track_width &&
       old_track_height && pos->height == old_track_height &&
+      pos->track_height && pos->track_width &&
       ((float) old_track_width / (float) old_track_height) ==
       ((float) pos->track_width / (float) pos->track_height)) {
 
@@ -438,14 +439,14 @@ gst_frame_positioner_get_info (void)
 {
   static const GstMetaInfo *meta_info = NULL;
 
-  if (g_once_init_enter (&meta_info)) {
+  if (g_once_init_enter ((GstMetaInfo **) & meta_info)) {
     const GstMetaInfo *meta =
         gst_meta_register (gst_frame_positioner_meta_api_get_type (),
         "GstFramePositionerMeta",
         sizeof (GstFramePositionerMeta), gst_frame_positioner_meta_init,
         NULL,
         gst_frame_positioner_meta_transform);
-    g_once_init_leave (&meta_info, meta);
+    g_once_init_leave ((GstMetaInfo **) & meta_info, (GstMetaInfo *) meta);
   }
   return meta_info;
 }
